@@ -26,6 +26,7 @@ class ImageModelTraining:
                 f"If you are using Google Colab, you may want to change the runtime to use a GPU or TPU by "
                 f"selecting 'Runtime' -> 'Change runtime type'.")
         self.evaluate_predictions = None
+        self.is_colored = self.images_data.is_colored
 
     def get_model(self):
         supported_models = ["EfficientNetB0", "EfficientNetB4", "EfficientNetB7", "ResNet50", "ResNet101",
@@ -99,18 +100,22 @@ class ImageModelTraining:
 
     def train_model_epoch(self, model, dataloader, criterion, optimizer):
         running_loss = 0.0
-        for i, (inputs, labels) in enumerate(dataloader, 0):
+        for i, (inputs_raw, labels) in enumerate(dataloader, 0):
             optimizer.zero_grad()
 
-            inputs, labels = inputs.to(self.device).float(), labels.to(self.device)
-
+            if self.is_colored:
+                inputs, labels = inputs_raw.to(self.device).float(), labels.to(self.device)
+            else:
+                # Add a new dimension to the input tensors to represent the grayscale channel
+                inputs_gray = inputs_raw.unsqueeze(1)
+                inputs = torch.cat([inputs_gray, inputs_gray, inputs_gray], dim=1)
+                inputs, labels = inputs.to(self.device).float(), labels.to(self.device)
             try:
                 model = model.to(self.device)
                 outputs = model(inputs).to(self.device)
             except Exception as e:
                 print(f"Error while running model: {e}")
                 print("Input size:", inputs.size())
-
             loss = criterion(outputs, labels)
             loss.backward()
 
@@ -122,16 +127,22 @@ class ImageModelTraining:
 
         return epoch_loss
 
-    @staticmethod
-    def evaluate_model(model, data_loader, device):
+    def evaluate_model(self, model, data_loader, device):
         correct = 0
         total = 0
         with torch.no_grad():
             for data in data_loader:
                 images, labels = data
-                images, labels = images.to(device).float(), labels.to(device)
 
-                outputs = model(images).to(device)
+                if self.is_colored:
+                    inputs, labels = images.to(device).float(), labels.to(device)
+                else:
+                    # Add a new dimension to the input tensors to represent the grayscale channel
+                    inputs_gray = images.unsqueeze(1)
+                    inputs = torch.cat([inputs_gray, inputs_gray, inputs_gray], dim=1)
+                    inputs, labels = inputs.to(self.device).float(), labels.to(self.device)
+
+                outputs = model(inputs).to(device)
                 _, predicted = torch.max(outputs.data, 1)
                 total += labels.size(0)
                 correct += (predicted == labels).sum().item()
@@ -139,15 +150,23 @@ class ImageModelTraining:
         accuracy = correct / total
         return accuracy
 
-    @staticmethod
-    def get_eval_prediction(model, data_loader, device, num_classes):
+    def get_eval_prediction(self, model, data_loader, device):
         # Get the predictions for the eval set
         eval_preds = []
         with torch.no_grad():
             for data in data_loader:
                 images, labels = data
                 images, labels = images.to(device).float(), labels.to(device)
-                outputs = model(images).to(device)
+
+                if self.is_colored:
+                    inputs = images.to(device).float()
+                else:
+                    # Add a new dimension to the input tensors to represent the grayscale channel
+                    inputs_gray = images.unsqueeze(1)
+                    inputs = torch.cat([inputs_gray, inputs_gray, inputs_gray], dim=1)
+                    inputs = inputs.to(self.device).float()
+
+                outputs = model(inputs).to(device)
                 for i in range(outputs.size(0)):  # iterate over batch size
                     output = outputs[i]
                     _, predicted = torch.max(output, 0)
@@ -162,6 +181,5 @@ class ImageModelTraining:
         print("\nTraining Specifications: ", self.image_model.network_parameters)
         optimizer = optim.Adam(model.parameters(), **optimizer_params)  # get rid of lr
         train_loss, val_loss = self.train_model(model, criterion, optimizer)  # get rid of epochs
-        self.evaluate_predictions = self.get_eval_prediction(
-            model, self.val_loader, num_classes=self.num_classes, device=self.device)
+        self.evaluate_predictions = self.get_eval_prediction(model, self.val_loader, device=self.device)
         return model, train_loss, val_loss, self.evaluate_predictions
